@@ -1,3 +1,3 @@
-AT_KEY = "keyTwvQWYVoC8xRym"
+AT_KEY = ""
 AT_URL_USERS = "https://api.airtable.com/v0/app2tERKciv4IcpYk/Users?maxRecords=1&view=Master%20View"
 AT_URL_SINGLE_USER = "https://api.airtable.com/v0/app2tERKciv4IcpYk/Users/"
